@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2011-2024  Ruby-GNOME Project Team
+ *  Copyright (C) 2011-2025  Ruby-GNOME Project Team
  *  Copyright (C) 2002,2003  Masahiro Sakai
  *
  *  This library is free software; you can redistribute it and/or
@@ -23,16 +23,18 @@
 #include "rbgprivate.h"
 #include "rbglib.h"
 
-#define RG_TARGET_NAMESPACE mGLib
+#define RG_TARGET_NAMESPACE rbg_mGLib()
 
 static ID id_inspect;
 
-VALUE RG_TARGET_NAMESPACE;
+VALUE mGLib;
 
 VALUE
 rbg_mGLib(void)
 {
-    return RG_TARGET_NAMESPACE;
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+    return mGLib;
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 const gchar *
@@ -1105,7 +1107,9 @@ Init_glib2(void)
 
     id_inspect = rb_intern("inspect");
 
-    RG_TARGET_NAMESPACE = rb_define_module("GLib");
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+    mGLib = rb_define_module("GLib");
+G_GNUC_END_IGNORE_DEPRECATIONS
 
     setlocale (LC_CTYPE, "");
 #ifdef LC_MESSAGES
@@ -1157,7 +1161,7 @@ Init_glib2(void)
     rb_define_const(RG_TARGET_NAMESPACE, "MAXINT16", INT2FIX(G_MAXINT16));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXUINT16", UINT2NUM(G_MAXUINT16));
 
-    rb_define_const(RG_TARGET_NAMESPACE, "MININT32", INT2FIX(G_MININT32));
+    rb_define_const(RG_TARGET_NAMESPACE, "MININT32", INT2NUM(G_MININT32));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXINT32", INT2NUM(G_MAXINT32));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXUINT32", UINT2NUM(G_MAXUINT32));
 
